@@ -1,4 +1,5 @@
 """Assorted auxiliary functions"""
+from datetime import datetime
 from typing import Any
 
 
@@ -25,3 +26,13 @@ def version() -> str:
     import pkg_resources
 
     return pkg_resources.require("duffel_api")[0].version
+
+
+def parse_datetime(value: str) -> datetime:
+    """Parse a datetime string regardless of having milliseconds or not"""
+    # There are inconsistent formats used for the field, therefore we try to accomodate
+    # instead of making an API breaking change.
+    if len(value) == 20:
+        return datetime.strptime(value, "%Y-%m-%dT%H:%M:%SZ")
+    else:
+        return datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%fZ")
